@@ -1,12 +1,22 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -52,7 +62,8 @@ MainWindow::MainWindow(QWidget *parent)
 
     // Populate engine selection list
     ui.engine->addItem("Default", QString("default"));
-    foreach (QString engine, QTextToSpeech::availableEngines())
+    const auto engines = QTextToSpeech::availableEngines();
+    for (const QString &engine : engines)
         ui.engine->addItem(engine, engine);
     ui.engine->setCurrentIndex(0);
     engineSelected(0);
@@ -115,9 +126,9 @@ void MainWindow::engineSelected(int index)
     disconnect(ui.language, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &MainWindow::languageSelected);
     ui.language->clear();
     // Populate the languages combobox before connecting its signal.
-    QVector<QLocale> locales = m_speech->availableLocales();
+    const QVector<QLocale> locales = m_speech->availableLocales();
     QLocale current = m_speech->locale();
-    foreach (const QLocale &locale, locales) {
+    for (const QLocale &locale : locales) {
         QString name(QString("%1 (%2)")
                      .arg(QLocale::languageToString(locale.language()))
                      .arg(QLocale::countryToString(locale.country())));
@@ -161,7 +172,7 @@ void MainWindow::localeChanged(const QLocale &locale)
 
     m_voices = m_speech->availableVoices();
     QVoice currentVoice = m_speech->voice();
-    foreach (const QVoice &voice, m_voices) {
+    for (const QVoice &voice : qAsConst(m_voices)) {
         ui.voice->addItem(QString("%1 - %2 - %3").arg(voice.name())
                           .arg(QVoice::genderName(voice.gender()))
                           .arg(QVoice::ageName(voice.age())));
