@@ -63,7 +63,6 @@
 #include <QFileDialog>
 #include <QDialogButtonBox>
 #include <QMessageBox>
-#include <QSignalMapper>
 #include <QApplication>
 #include <QPainter>
 #include <QMouseEvent>
@@ -98,6 +97,7 @@ MainWindow::MainWindow(const CustomSizeHintMap &customSizeHints,
                        QWidget *parent, Qt::WindowFlags flags)
     : QMainWindow(parent, flags)
 {
+    Q_UNUSED(message);
     setObjectName("MainWindow");
     setWindowTitle("Qt Main Window Example");
 
@@ -188,6 +188,13 @@ void MainWindow::setupMenuBar()
 #endif
 
     dockWidgetMenu = menuBar()->addMenu(tr("&Dock Widgets"));
+
+    QMenu *aboutMenu = menuBar()->addMenu(tr("About"));
+    QAction *aboutAct = aboutMenu->addAction(tr("&About"), this, &MainWindow::about);
+    aboutAct->setStatusTip(tr("Show the application's About box"));
+
+    QAction *aboutQtAct = aboutMenu->addAction(tr("About &Qt"), qApp, &QApplication::aboutQt);
+    aboutQtAct->setStatusTip(tr("Show the Qt library's About box"));
 }
 
 void MainWindow::setDockOptions()
@@ -282,23 +289,10 @@ void MainWindow::loadLayout()
     }
 }
 
-class DockWidgetAreaCornerFunctor {
-public:
-    explicit DockWidgetAreaCornerFunctor(QMainWindow *mw, Qt::Corner c, Qt::DockWidgetArea a)
-        : m_mainWindow(mw), m_area(a), m_corner(c) {}
-
-    void operator()() const { m_mainWindow->setCorner(m_corner, m_area); }
-
-private:
-    QMainWindow *m_mainWindow;
-    Qt::DockWidgetArea m_area;
-    Qt::Corner m_corner;
-};
-
 static QAction *addCornerAction(const QString &text, QMainWindow *mw, QMenu *menu, QActionGroup *group,
                                 Qt::Corner c, Qt::DockWidgetArea a)
 {
-    QAction *result = menu->addAction(text, mw, DockWidgetAreaCornerFunctor(mw, c, a));
+    QAction *result = menu->addAction(text, mw, [=]() { mw->setCorner(c, a); });
     result->setCheckable(true);
     group->addAction(result);
     return result;
@@ -396,7 +390,7 @@ void MainWindow::switchLayoutDirection()
 class CreateDockWidgetDialog : public QDialog
 {
 public:
-    explicit CreateDockWidgetDialog(QWidget *parent = Q_NULLPTR);
+    explicit CreateDockWidgetDialog(QWidget *parent = nullptr);
 
     QString enteredObjectName() const { return m_objectName->text(); }
     Qt::DockWidgetArea location() const;
@@ -490,3 +484,8 @@ void MainWindow::destroyDockWidget(QAction *action)
     if (destroyDockWidgetMenu->isEmpty())
         destroyDockWidgetMenu->setEnabled(false);
 }
+
+void MainWindow::about()
+{
+    QMessageBox::about(this, tr("About MainWindows"), message);
+}
